==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/gcp/v1/EncryptionKeyReferenceBuilder.java <==
package io.fabric8.openshift.api.model.hive.gcp.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EncryptionKeyReferenceBuilder extends EncryptionKeyReferenceFluentImpl<EncryptionKeyReferenceBuilder> implements VisitableBuilder<EncryptionKeyReference,EncryptionKeyReferenceBuilder>{
  public EncryptionKeyReferenceBuilder() {
    this(false);
  }
  public EncryptionKeyReferenceBuilder(Boolean validationEnabled) {
    this(new EncryptionKeyReference(), validationEnabled);
  }
  public EncryptionKeyReferenceBuilder(EncryptionKeyReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public EncryptionKeyReferenceBuilder(EncryptionKeyReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EncryptionKeyReference(), validationEnabled);
  }
  public EncryptionKeyReferenceBuilder(EncryptionKeyReferenceFluent<?> fluent,EncryptionKeyReference instance) {
    this(fluent, instance, false);
  }
  public EncryptionKeyReferenceBuilder(EncryptionKeyReferenceFluent<?> fluent,EncryptionKeyReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withKmsKey(instance.getKmsKey());
      fluent.withKmsKeyServiceAccount(instance.getKmsKeyServiceAccount());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EncryptionKeyReferenceBuilder(EncryptionKeyReference instance) {
    this(instance,false);
  }
  public EncryptionKeyReferenceBuilder(EncryptionKeyReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withKmsKey(instance.getKmsKey());
      this.withKmsKeyServiceAccount(instance.getKmsKeyServiceAccount());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EncryptionKeyReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public EncryptionKeyReference build() {
    EncryptionKeyReference buildable = new EncryptionKeyReference(fluent.getKmsKey(),fluent.getKmsKeyServiceAccount());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/gcp/v1/EncryptionKeyReferenceBuilder.java <==
package io.fabric8.openshift.api.model.hive.gcp.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EncryptionKeyReferenceBuilder extends EncryptionKeyReferenceFluent<EncryptionKeyReferenceBuilder> implements VisitableBuilder<EncryptionKeyReference,EncryptionKeyReferenceBuilder>{
  public EncryptionKeyReferenceBuilder() {
    this(false);
  }
  public EncryptionKeyReferenceBuilder(Boolean validationEnabled) {
    this(new EncryptionKeyReference(), validationEnabled);
  }
  public EncryptionKeyReferenceBuilder(EncryptionKeyReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public EncryptionKeyReferenceBuilder(EncryptionKeyReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EncryptionKeyReference(), validationEnabled);
  }
  public EncryptionKeyReferenceBuilder(EncryptionKeyReferenceFluent<?> fluent,EncryptionKeyReference instance) {
    this(fluent, instance, false);
  }
  public EncryptionKeyReferenceBuilder(EncryptionKeyReferenceFluent<?> fluent,EncryptionKeyReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EncryptionKeyReference());

    if (instance != null) {
      fluent.withKmsKey(instance.getKmsKey());
      fluent.withKmsKeyServiceAccount(instance.getKmsKeyServiceAccount());
      fluent.withKmsKey(instance.getKmsKey());
      fluent.withKmsKeyServiceAccount(instance.getKmsKeyServiceAccount());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EncryptionKeyReferenceBuilder(EncryptionKeyReference instance) {
    this(instance,false);
  }
  public EncryptionKeyReferenceBuilder(EncryptionKeyReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EncryptionKeyReference());

    if (instance != null) {
      this.withKmsKey(instance.getKmsKey());
      this.withKmsKeyServiceAccount(instance.getKmsKeyServiceAccount());
      this.withKmsKey(instance.getKmsKey());
      this.withKmsKeyServiceAccount(instance.getKmsKeyServiceAccount());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EncryptionKeyReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public EncryptionKeyReference build() {
    EncryptionKeyReference buildable = new EncryptionKeyReference(fluent.buildKmsKey(),fluent.getKmsKeyServiceAccount());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
